@@ -21,7 +21,7 @@ try:
     if VERBOSE: print('Detected numpy version {__version__}'.format(**locals()))
 
 except ImportError:
-    print('Numpy is not found! Finding primes will be slower!')
+    print('numpy is not found! Finding primes will be slower!')
     NUMPY_ENABLED = False
 
 MPMATH_ENABLED = True
@@ -30,7 +30,7 @@ try:
     if VERBOSE: print('Detected mpmath version {__version__}'.format(**locals()))
 
 except ImportError:
-    print('Mpmath is not found! You can\'t find several kinds of primes!')
+    print('mpmath is not found! You can\'t find unique primes!')
     MPMATH_ENABLED = False
 
 PRIME_TEST = FACTOR_TEST = not DEBUG
@@ -40,7 +40,7 @@ try:
     if VERBOSE: print('Detected rsa version {__version__}'.format(**locals()))
 
 except ImportError:
-    print('Rsa is not found! Factor Test will be disabled!')
+    print('rsa is not found! Factor tests will be disabled!')
     FACTOR_TEST = False
 
 if VERBOSE: print()
@@ -65,7 +65,7 @@ class FactorError(Exception):
 
 def _check_num(n):
     '''
-    Internel function to check the input.
+    Internal function to check the input.
     '''
     if not isinstance(n, int):
         raise TypeError('Type of argument n should be int, got {type(n).__name__}'.format(**locals()))
@@ -75,7 +75,7 @@ def _check_num(n):
 
 def _check_factors(ans, n, retry = 1, max_retries = 3):
     '''
-    Internel function to check the output.
+    Internal function to check the output.
     '''
     if reduce(mul, ans) == n:
         return 0
@@ -281,7 +281,7 @@ def find_palindromes(n):
     palin_primes = []
     for ix, xp in enumerate(primes):
         palin_num = int(str(xp)[::-1])
-        if is_prime(palin_num) and palin_num == xp and xp > 10:
+        if is_prime(palin_num) and palin_num == xp:
             palin_primes.append(palin_num)
 
     return palin_primes
@@ -310,7 +310,7 @@ def find_reverses(n):
     reverse_primes = {}
     for ix, xp in enumerate(primes):
         reverse_num = int(str(xp)[::-1])
-        if is_prime(reverse_num) and xp > 10:
+        if is_prime(reverse_num):
             reverse_primes[xp] = reverse_num
 
     palin_primes = find_palindromes(n)
