@@ -1,10 +1,13 @@
-from requests import get
 from unittest import TestCase, main
+from sys import exit
+from find_primes import *
+
 try:
-    from .find_primes import *
+    from requests import get
 
 except ImportError:
-    from find_primes import *
+    print('requests is not found! Test won\'t run!!')
+    exit()
 
 def get_answer(string):
     try:
